@@ -114,7 +114,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.7.1'
+VERSION = '0.7.2'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -714,7 +714,7 @@ def _build_werkzeug_request_data(request):
     }
 
     if request.get_json():
-        request_data['body'] = _scrub_request_params(request.json)
+        request_data['body'] = json.dumps(_scrub_request_params(request.json))
 
     return request_data
 
